<kbd>
  <img src="https://image.ibb.co/ePxtKU/main_image.png">
</kbd>

## Description

biosignalsnotebooks is set of notebooks and a python library to provide programming examples in the form of [**Jupyter notebooks**](https://jupyter-notebook.readthedocs.io/en/latest/notebook.html), as companion to the [**OpenSignals**](http://biosignalsplux.com/en/software/opensignals) biosignals acquisition tools.

This collection of code samples has the purpose to help  users of [*PLUX Wireless Biosignals*](https://www.plux.info/index.php/en/) systems, such as [**bitalino**](http://bitalino.com/en/) or [**biosignalsplux**](http://biosignalsplux.com/en/), and to the researcher or student interested on recording processing and classifying biosignals signals. The examples are set on a level of complexity to inspire the users and programmers on how easy some tasks are and that more complex ones can also be achieved, by reusing and recreating some of the examples presented here.

A [*Python*](https://www.python.org/) library (entitled *biosignalsnotebooks* <link to PyPi>) is the base toolbox to support the notebooks and to provide some base
In many cases we also point and illustrate with code the usage of other [python toolboxes](https://github.com/novabiosignals/biosignalsnotebooks/blob/master/OSTLIBRARIES.md) dedicated to biosignal processing.

The notebooks will cover the full topics pipeline of working with biosignals: **Open** a file; **Visualize** the data online and offline, **Process** a one channel signal or a multi-channel acquisition, **Detect** relevant events in the signals, **Extract** features from many different type of sensors and domains, **Decide** among a set of classes with several machine learning approaches, **Explain** the obtained results with metrics and validations techniques.

These examples are  carried in a multitude of [biosignals <link to the page with notebooks grouped by signals used>](Biosignals.md), from **ECG**, **EDA**, **EMG**, **Accelerometer**, **Respiration** among many others.

The notebooks have a set of labels to help navigate among [topics <...>](Topics.md), types of [signals <...>](Biosignlas.md), [application area <...>](Areas.md) and [complexity <...>](Complexity.md) level to support the search for particular solutions.

We encourage you to share new example ideas, to pose questions :::ADD email here:::, and to make improvements or suggestion to this set of notebooks.

Be inspired on how to make the most of your **biosignals**!


## What is **OpenSignals**

[**OpenSignals**](http://biosignalsplux.com/en/software/opensignals) is the companion application to *Plux* devices ([**bitalino**](http://bitalino.com/en/) or [**biosignalsplux**](http://biosignalsplux.com/en/)) where the users collect visualize an process biosignals in a intuitive user interface. Opensignals is free and can be used also with signals collected form other devices.

In some cases **OpenSignals** provides [*plugins*](http://biosignalsplux.com/en/software/add-ons) for advanced signals processing operations that automate some of the research process. Some of the plugins are curated and advanced versions of the base notebooks explained in here.

The list of plugins can be found here: http://biosignalsplux.com/en/software/add-ons

## What is **PLUX**

PLUX wireless biosignals is devoted to the creation innovative products for advanced biosignals monitoring platforms
that integrate wearable body sensors combined with wireless connectivity, algorithms and software applications.

We have been perusing the mission of making biosignals as accessible as possible to researchers and students in many areas of application, ranging from biomedical engineering, computer science, human computer interaction, sport sciences, psychology, clinical research among other fields.

## Access to biosignalsnotebooks Notebooks

<a href="http://www.opensignals.net">
    <p align="center">
      <img src="https://image.ibb.co/fRStKU/osf_logo.gif" width="40%">
    </p>
</a>

## Installation of biosignalsnotebooks package
In order to *biosignalsnotebooks* package be installed, the user should open a Windows command prompt (by searching for "cmd") and type the following instruction:
```
pip install biosignalsnotebooks
```
